Welcome to Catalight!
=======================
.. figure:: /docs/source/_static/images/catalight_header_g.png
    :width: 800

Introduction
------------
Catalight is tool set developed by scientists at Stanford to help automate photocatalysis experiments. catalight is capable of connecting to hardware, coordinating instruments to run a variety of different experimental procedures, and organizing and analyzing data collected by the system. The project is designed in a modular format to enable users to bring their own unique hardware while still utilizing the core features of experiment management and data handling. The program functions in both a scripted version and a GUI to aid users in planning experimental procedures and manually controlling hardware.

To date, catalight is compatible with Alicat mass flow controllers, heater systems controlled by Watlow components, Measurement Computing data acquisition boards (used for communication with (ThorLabs laser diode drivers), NewPort 843-R power meter, and SRI gas chromatographs. Support for additional hardware is planned for the future, including FTIR data collection and analysis and NKT Photonics lasers. We strongly encourage interested users to consider contributing to the project by adding new device support and helping expand the catalight functionality.

**Link to ReadtheDocs Page Coming Soon**
----------------------------------------

.. figure:: /docs/source/_static/images/overview.png
    :width: 800

    D-Lab Hardware Configuration
